==> tasks-v1.8.8.zip: tasks/messages/ru/base.php <==
<?php

return [
    '1 Day before' => 'За 1 день до',
    '1 Month before' => 'За 1 месяц до',
    '1 Week before' => 'За 1 неделю до',
    '2 Days before' => 'За 2 дня до',
    '2 Weeks before' => 'За 2 недели до',
    '3 Weeks before' => 'За 3 недели до',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Назначенным пользователям</strong> разрешено обрабатывать эту задачу.',
    '<strong>Confirm</strong> task deletion' => '<strong>Подтвердить</strong> удаление задачи',
    '<strong>Create</strong> task list' => '<strong>Создать</strong> список задач',
    '<strong>Edit</strong> task' => '<strong>Редактировать</strong> задачу',
    '<strong>Edit</strong> task list' => '<strong>Редактировать</strong> список задач',
    '<strong>New</strong> Task' => '<strong>Новая</strong> задача',
    '<strong>Task</strong> Overview' => 'Обзор <strong>задач</strong>',
    '<strong>Tasks</strong>' => '<strong>Задачи</strong>',
    '<strong>Your</strong> tasks' => 'Ваши <strong>задачи</strong>',
    'Accept Task' => 'Принять задание',
    'Add Deadline to space calendar' => 'Добавить Крайний Срок в календарь сообществ',
    'Add checkpoint...' => 'Добавьте контрольный пункт...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Добавьте контрольные/проверочные пункты к задаче, чтобы выделить отдельные шаги, необходимые для ее выполнения.',
    'Add entry to main navigation' => 'Добавить пункт меню в основную навигацию',
    'Add reminder' => 'Добавить напоминание',
    'Add responsible users' => 'Добавление ответственных пользователей для задачи',
    'Add schedule to the space calendar' => 'Добавить расписание в календарь сообщества',
    'Add task' => 'Добавить задачу',
    'Add to space calendar' => 'Добавить в календарь сообщества',
    'Additional options' => 'Дополнительные опции',
    'All Day' => 'Весь день',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Позволяет пользователю создавать задачи, пользователь сможет редактировать и удалять только свои задачи',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Позволяет пользователю создавать, удалять и редактировать задачи и списки задач, а также сортировать задачи и списки задач',
    'Allows the user to process unassigned tasks' => 'Позволяет пользователю выполнять неназначенные задачи',
    'Already requested' => 'Уже запрошен',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Любой пользователь с разрешением "Выполнять неназначенные задачи" может работать над этой задачей',
    'Anyone can work on this task!' => 'Любой желающий может работать над этой задачей!',
    'Assign myself' => 'Назначить себя',
    'Assign users' => 'Назначить пользователей',
    'Assigned' => 'Назначен',
    'Assigned users' => 'Назначенные пользователи',
    'Assignment' => 'Назначение',
    'Assignments:' => 'Назначения:',
    'At least 1 Hour before' => 'Хотя бы за 1 час до',
    'At least 2 Hours before' => 'Хотя бы за 2 часа до',
    'Attachments' => 'Вложения',
    'Begin Task' => 'Приступить к выполнению задачи',
    'Checklist Items' => 'Пункты контрольного списка',
    'Checklist:' => 'Контрольный список:',
    'Checkpoints' => 'Контрольные пункты',
    'Close' => 'Закрыть',
    'Color' => 'Цвет',
    'Completed' => 'Выполнено',
    'Continue Review' => 'Включить режим на рассмотрении',
    'Create tasks' => 'Добавить задачи',
    'Created by me' => 'Создано мной',
    'Date' => 'Дата',
    'Deadline at' => 'Крайний срок',
    'Deadline: ' => 'Крайний срок: ',
    'Delete' => 'Удалить',
    'Delete list' => 'Удалить список',
    'Description' => 'Описание',
    'Do not remind' => 'Без напоминаний',
    'Do you really want to delete this task?' => 'Вы действительно хотите удалить эту задачу?',
    'Don\'t add to calendar' => 'Не добавлять в календарь',
    'Drag entry' => 'Перенести запись',
    'Edit' => 'Изменить',
    'Edit item (empty field will be removed)...' => 'Отредактируйте элемент (пустое поле будет удалено)...',
    'Edit list' => 'Редактировать список задач',
    'End' => 'Конец',
    'End Date' => 'Дата окончания',
    'End Time' => 'Время окончания',
    'End date' => 'Дата конца',
    'End time must be after start time!' => 'Время окончания должно быть позже начала',
    'Extend deadline request' => 'Запрос на продление крайнего срока',
    'Filter' => 'Фильтр',
    'Filter by status' => 'Сортировать по статусу',
    'Filter by title' => 'Сортировать по названию',
    'Filter tasks' => 'Фильтровать задачи',
    'Finish Task' => 'Завершить задачу',
    'General' => 'Основная информация',
    'General Settings' => 'Общие настройки',
    'Hide this list once all tasks are completed' => 'Скройте этот список, как только все задачи будут выполнены',
    'I\'m assigned' => 'Я назначен',
    'I\'m responsible' => 'Я ответственный',
    'If empty any user can complete the task.' => 'Если оставить поле пустым, тогда любой пользователь может выполнить задачу.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Если не добавлены назначенные пользователи, каждый участник сообщества, имеющий разрешение на обработку неназначенных задач, может обработать задачу.',
    'In Progress' => 'В процессе',
    'In Review' => 'На расмотрении',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'В случае, если опция проверки активна, <strong>ответственный пользователь</strong> должен будет просмотреть и либо отклонить, либо подтвердить эту задачу до завершения.',
    'Invalid task list selection.' => 'Неверный выбор списка задач.',
    'Let Task Review' => 'Разрешить рассмотрение задачи',
    'Main Navigation' => 'Основная навигация',
    'Manage tasks' => 'Управление задачами',
    'Maximum number of entries in widget' => 'Максимальное количество записей в виджете',
    'Module Widget' => 'Виджет модуля',
    'No Scheduling set for this Task' => 'Для этой задачи нет графика выполнения',
    'No pending tasks found' => 'Не найдено отложенных задач',
    'No results found for the given filter.' => 'По данному поиску результатов не найдено.',
    'Open Task' => 'Просмотр задачи',
    'Other Tasks' => 'Другие задачи',
    'Overdue' => 'Просроченная',
    'Overview' => 'Обзор задач',
    'Parent Task' => 'Родительская задача',
    'Pending' => 'В ожидании',
    'Pending Review' => 'Ожидающий рассмотрения',
    'Process unassigned tasks' => 'Обрабатывать неназначенные задачи',
    'Ready For Review' => 'Готов к рассмотрению',
    'Receive Notifications for Task Reminder.' => 'Получайте уведомления о напоминании о задаче.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Получайте уведомления о задачах (Обновление крайних сроков, изменение статуса ...).',
    'Reject Task' => 'Отклонить задачу',
    'Remind Mode' => 'Режим напоминания',
    'Reminder' => 'Напоминание',
    'Reminder sent' => 'Напоминание отправлено',
    'Reminders' => 'Напоминания',
    'Request extension' => 'Запрос на продление',
    'Request sent' => 'Запрос отправлен',
    'Reset Task' => 'Сброс задачи',
    'Responsible' => 'Ответственный',
    'Responsible users' => 'Ответственные пользователи',
    'Review by responsible user required' => 'Требуется проверка ответственным пользователем',
    'Scheduling' => 'Назначение сроков',
    'Show widget in Spaces' => 'Показать виджет в сообществе',
    'Show widget on Dashboard' => 'Показать виджет на Приборной панели (Dashboard)',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Показать {count} выполненных задач {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Порядок сортировки',
    'Sort order' => 'Порядок сортировки',
    'Spaces' => 'Сообщества',
    'Start' => 'Старт',
    'Start Date' => 'Дата начала',
    'Start Time' => 'Время начала',
    'Start date' => 'Дата начала',
    'Starting at' => 'Начиная с ',
    'Status' => 'Статус',
    'Task' => 'Задача',
    'Task List' => 'Список задач',
    'Task Users have been notified' => 'Пользователи задач были уведомлены',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Задача {task} в сообществе {spaceName} заканчивается {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Задача {task} в сообществе {spaceName} начинается {dateTime}.',
    'Tasks' => 'Задачи',
    'Tasks: Reminder' => 'Задачи: Напоминание',
    'This task can only be processed by assigned and responsible users.' => 'Эта задача может быть выполнена только назначенными и ответственными пользователями.',
    'This task requires to be reviewed by a responsible' => 'Эта задача должна быть рассмотрена ответственным',
    'Time Zone' => 'Часовой пояс',
    'Title' => 'Заголовок',
    'Title and Color' => 'Наименование и цвет',
    'Title of your task list' => 'Наименование вашего списка задач',
    'Today' => 'Сегодня',
    'Unsorted' => 'Не отсортированный',
    'View Online' => 'Посмотреть на сайте',
    'You are assigned!' => 'Вы назначены!',
    'You are responsible!' => 'Вы ответственны!',
    'You have insufficient permissions to perform that operation!' => 'Вы должны иметь доступ на выполнение этой операции!',
    'Your Reminder for task {task}' => 'Напоминание о задаче {task}',
    'ending Review' => 'закончить Рассмотрение',
    'view all' => 'просмотреть все',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# день} other{# дней}} осталось',
    '{displayName} is assigned to this task' => '{displayName} назначен для этой задачи',
    '{displayName} is responsible for this task' => '{displayName} ответственный за эту задачу',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} назначил вас ответственным за задачу {task} в сообществе {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} назначил вам задачу {task} в сообществе {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} выполнил задачу {task} в сообществе {spaceName}. ',
    '{userName} completed task {task}.' => '{userName} выполнил задачу {task}.',
    '{userName} finished task {task}.' => '{userName} завершил задачу {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} изменил крайний срок выполнения задачи {task} в сообществе {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} повторно открыл задачу {task} в сообществе {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} отклонил задачу {task} в сообществе {spaceName} так как посчитал невыполненной до конца.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} пометил задачу {task} в сообществе {spaceName} как выполненную.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} запрашивает продление крайнего срока для задачи {task} в сообществе {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} просит вас проверить задачу {task} в сообществе {spaceName}. ',
    '{userName} reset task {task}.' => '{userName} сбросил задачу {task}.',
    '{userName} reviewed task {task}.' => '{userName} проверил задачу {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} начал работать над задачей {task} в сообществе {spaceName}.',
    '{userName} works on task {task}.' => '{userName} работает над задачей {task}.',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'New list or search' => '',
    'Task content ID' => '',
];

==> tasks-v1.9.1.zip: tasks/messages/ru/base.php <==
<?php

return [
    '1 Day before' => 'За 1 день до',
    '1 Month before' => 'За 1 месяц до',
    '1 Week before' => 'За 1 неделю до',
    '2 Days before' => 'За 2 дня до',
    '2 Weeks before' => 'За 2 недели до',
    '3 Weeks before' => 'За 3 недели до',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Назначенным пользователям</strong> разрешено обрабатывать эту задачу.',
    '<strong>Confirm</strong> task deletion' => '<strong>Подтвердить</strong> удаление задачи',
    '<strong>Create</strong> task list' => '<strong>Создать</strong> список задач',
    '<strong>Edit</strong> task' => '<strong>Редактировать</strong> задачу',
    '<strong>Edit</strong> task list' => '<strong>Редактировать</strong> список задач',
    '<strong>New</strong> Task' => '<strong>Новая</strong> задача',
    '<strong>Task</strong> Overview' => 'Обзор <strong>задач</strong>',
    '<strong>Tasks</strong>' => '<strong>Задачи</strong>',
    '<strong>Your</strong> tasks' => 'Ваши <strong>задачи</strong>',
    'Accept Task' => 'Принять задание',
    'Add Deadline to space calendar' => 'Добавить Крайний Срок в календарь сообществ',
    'Add checkpoint...' => 'Добавьте контрольный пункт...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Добавьте контрольные/проверочные пункты к задаче, чтобы выделить отдельные шаги, необходимые для ее выполнения.',
    'Add entry to main navigation' => 'Добавить пункт меню в основную навигацию',
    'Add reminder' => 'Добавить напоминание',
    'Add responsible users' => 'Добавление ответственных пользователей для задачи',
    'Add schedule to the space calendar' => 'Добавить расписание в календарь сообщества',
    'Add task' => 'Добавить задачу',
    'Add to space calendar' => 'Добавить в календарь сообщества',
    'Additional options' => 'Дополнительные опции',
    'All Day' => 'Весь день',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Позволяет пользователю создавать задачи, пользователь сможет редактировать и удалять только свои задачи',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Позволяет пользователю создавать, удалять и редактировать задачи и списки задач, а также сортировать задачи и списки задач',
    'Allows the user to process unassigned tasks' => 'Позволяет пользователю выполнять неназначенные задачи',
    'Already requested' => 'Уже запрошен',
    'Assign myself' => 'Назначить себя',
    'Assign users' => 'Назначить пользователей',
    'Assigned users' => 'Назначенные пользователи',
    'Assignment' => 'Назначение',
    'At least 1 Hour before' => 'Хотя бы за 1 час до',
    'At least 2 Hours before' => 'Хотя бы за 2 часа до',
    'Attachments' => 'Вложения',
    'Begin Task' => 'Приступить к выполнению задачи',
    'Checklist Items' => 'Пункты контрольного списка',
    'Checklist:' => 'Контрольный список:',
    'Checkpoints' => 'Контрольные пункты',
    'Close' => 'Закрыть',
    'Color' => 'Цвет',
    'Completed' => 'Выполнено',
    'Continue Review' => 'Включить режим на рассмотрении',
    'Create tasks' => 'Добавить задачи',
    'Created by me' => 'Создано мной',
    'Date' => 'Дата',
    'Deadline: ' => 'Крайний срок: ',
    'Delete' => 'Удалить',
    'Delete list' => 'Удалить список',
    'Description' => 'Описание',
    'Do not remind' => 'Без напоминаний',
    'Do you really want to delete this task?' => 'Вы действительно хотите удалить эту задачу?',
    'Don\'t add to calendar' => 'Не добавлять в календарь',
    'Edit' => 'Изменить',
    'Edit item (empty field will be removed)...' => 'Отредактируйте элемент (пустое поле будет удалено)...',
    'Edit list' => 'Редактировать список задач',
    'End' => 'Конец',
    'End Date' => 'Дата окончания',
    'End Time' => 'Время окончания',
    'End date' => 'Дата конца',
    'End time must be after start time!' => 'Время окончания должно быть позже начала',
    'Extend deadline request' => 'Запрос на продление крайнего срока',
    'Filter' => 'Фильтр',
    'Filter by status' => 'Сортировать по статусу',
    'Filter by title' => 'Сортировать по названию',
    'Filter tasks' => 'Фильтровать задачи',
    'Finish Task' => 'Завершить задачу',
    'General' => 'Основная информация',
    'General Settings' => 'Общие настройки',
    'Hide this list once all tasks are completed' => 'Скройте этот список, как только все задачи будут выполнены',
    'I\'m assigned' => 'Я назначен',
    'I\'m responsible' => 'Я ответственный',
    'If empty any user can complete the task.' => 'Если оставить поле пустым, тогда любой пользователь может выполнить задачу.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Если не добавлены назначенные пользователи, каждый участник сообщества, имеющий разрешение на обработку неназначенных задач, может обработать задачу.',
    'In Progress' => 'В процессе',
    'In Review' => 'На расмотрении',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'В случае, если опция проверки активна, <strong>ответственный пользователь</strong> должен будет просмотреть и либо отклонить, либо подтвердить эту задачу до завершения.',
    'Invalid task list selection.' => 'Неверный выбор списка задач.',
    'Let Task Review' => 'Разрешить рассмотрение задачи',
    'Main Navigation' => 'Основная навигация',
    'Manage tasks' => 'Управление задачами',
    'Maximum number of entries in widget' => 'Максимальное количество записей в виджете',
    'Module Widget' => 'Виджет модуля',
    'No Scheduling set for this Task' => 'Для этой задачи нет графика выполнения',
    'No pending tasks found' => 'Не найдено отложенных задач',
    'No results found for the given filter.' => 'По данному поиску результатов не найдено.',
    'Open Task' => 'Просмотр задачи',
    'Other Tasks' => 'Другие задачи',
    'Overdue' => 'Просроченная',
    'Overview' => 'Обзор задач',
    'Parent Task' => 'Родительская задача',
    'Pending' => 'В ожидании',
    'Pending Review' => 'Ожидающий рассмотрения',
    'Process unassigned tasks' => 'Обрабатывать неназначенные задачи',
    'Ready For Review' => 'Готов к рассмотрению',
    'Receive Notifications for Task Reminder.' => 'Получайте уведомления о напоминании о задаче.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Получайте уведомления о задачах (Обновление крайних сроков, изменение статуса ...).',
    'Reject Task' => 'Отклонить задачу',
    'Remind Mode' => 'Режим напоминания',
    'Reminder' => 'Напоминание',
    'Reminder sent' => 'Напоминание отправлено',
    'Reminders' => 'Напоминания',
    'Request extension' => 'Запрос на продление',
    'Request sent' => 'Запрос отправлен',
    'Reset Task' => 'Сброс задачи',
    'Responsible' => 'Ответственный',
    'Responsible users' => 'Ответственные пользователи',
    'Review by responsible user required' => 'Требуется проверка ответственным пользователем',
    'Scheduling' => 'Назначение сроков',
    'Show widget in Spaces' => 'Показать виджет в сообществе',
    'Show widget on Dashboard' => 'Показать виджет на Приборной панели (Dashboard)',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Показать {count} выполненных задач {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Порядок сортировки',
    'Sort order' => 'Порядок сортировки',
    'Spaces' => 'Сообщества',
    'Start' => 'Старт',
    'Start Date' => 'Дата начала',
    'Start Time' => 'Время начала',
    'Start date' => 'Дата начала',
    'Starting at' => 'Начиная с ',
    'Status' => 'Статус',
    'Task' => 'Задача',
    'Task List' => 'Список задач',
    'Task Users have been notified' => 'Пользователи задач были уведомлены',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Задача {task} в сообществе {spaceName} заканчивается {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Задача {task} в сообществе {spaceName} начинается {dateTime}.',
    'Tasks' => 'Задачи',
    'Tasks: Reminder' => 'Задачи: Напоминание',
    'This task requires to be reviewed by a responsible' => 'Эта задача должна быть рассмотрена ответственным',
    'Time Zone' => 'Часовой пояс',
    'Title' => 'Заголовок',
    'Title and Color' => 'Наименование и цвет',
    'Title of your task list' => 'Наименование вашего списка задач',
    'Today' => 'Сегодня',
    'Unsorted' => 'Не отсортированный',
    'View Online' => 'Посмотреть на сайте',
    'You have insufficient permissions to perform that operation!' => 'Вы должны иметь доступ на выполнение этой операции!',
    'Your Reminder for task {task}' => 'Напоминание о задаче {task}',
    'view all' => 'просмотреть все',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# день} other{# дней}} осталось',
    '{displayName} is assigned to this task' => '{displayName} назначен для этой задачи',
    '{displayName} is responsible for this task' => '{displayName} ответственный за эту задачу',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} назначил вас ответственным за задачу {task} в сообществе {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} назначил вам задачу {task} в сообществе {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} выполнил задачу {task} в сообществе {spaceName}. ',
    '{userName} completed task {task}.' => '{userName} выполнил задачу {task}.',
    '{userName} finished task {task}.' => '{userName} завершил задачу {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} изменил крайний срок выполнения задачи {task} в сообществе {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} повторно открыл задачу {task} в сообществе {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} отклонил задачу {task} в сообществе {spaceName} так как посчитал невыполненной до конца.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} пометил задачу {task} в сообществе {spaceName} как выполненную.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} запрашивает продление крайнего срока для задачи {task} в сообществе {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} просит вас проверить задачу {task} в сообществе {spaceName}. ',
    '{userName} reset task {task}.' => '{userName} сбросил задачу {task}.',
    '{userName} reviewed task {task}.' => '{userName} проверил задачу {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} начал работать над задачей {task} в сообществе {spaceName}.',
    '{userName} works on task {task}.' => '{userName} работает над задачей {task}.',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Assignments' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Deadline' => '',
    'ID' => '',
    'New list or search' => '',
    'Request Review' => '',
    'Task content ID' => '',
    '{displayName} is task creator' => '',
];
